Learn R Programming

netrankr (version 2.0.0)

rank_intervals: Rank interval of nodes

Description

Calculate the maximal and minimal rank possible for each node in any ranking that is in accordance with the partial ranking P.

Usage

rank_intervals(P)

Value

An object of type netrankr_interval, a data frame with columns node, min_rank and max_rank.

Arguments

P

A partial ranking as matrix object calculated with neighborhood_inclusion or positional_dominance.

Author

David Schoch

Details

For exact rank probabilities use exact_rank_prob.

See Also

exact_rank_prob

Examples

Run this code
P <- matrix(c(0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, rep(0, 10)), 5, 5, byrow = TRUE)
rank_intervals(P)

Run the code above in your browser using DataLab