The spectral (or eigen) gap of a graph is the absolute
difference between the biggest and second biggest eigenvalue
of the adjacency matrix. To compare spectral gaps across networks, the fraction can be used.
Usage
spectral_gap(g, method = "frac")
Value
Numeric value
Arguments
g
igraph object
method
A string, either "frac" or "abs"
Author
David Schoch
Details
The spectral gap is bounded between 0 and 1 if method="frac", except for
complete graphs where the second largest eigenvalue is negative. The closer
the value to one, the bigger the gap. Edge weights are ignored.