powered by
Calculate the maximal and minimal rank possible for each node in any ranking that is in accordance with the partial ranking P.
P
rank_intervals(P)
An object of type netrankr_interval, a data frame with columns node, min_rank and max_rank.
node
min_rank
max_rank
A partial ranking as matrix object calculated with neighborhood_inclusion or positional_dominance.
David Schoch
For exact rank probabilities use exact_rank_prob.
exact_rank_prob
P <- matrix(c(0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, rep(0, 10)), 5, 5, byrow = TRUE) rank_intervals(P)
Run the code above in your browser using DataLab